==> improvements-2.0.3.tar.gz: improvements/assets/improvements.utils.js <==
(function ($) {

  /**
   * Beautifier browser url.
   */
  Drupal.beautifierBrowserUrl = function () {
    if (window.location.href.indexOf('%')) {
      window.history.replaceState(null, null, decodeURIComponent(window.location.pathname) + decodeURIComponent(window.location.search) + window.location.hash);
    }
  };

  /**
   * Replace string multiple.
   */
  Drupal.stringReplaceMultiple = function (string, values) {
    for (var searchValue in values) {
      if (values.hasOwnProperty(searchValue)) {
        string = string.replace(new RegExp(searchValue, 'g'), values[searchValue]);
      }
    }
    return string;
  };

  /**
   * Preload images.
   */
  Drupal.preloadImages = function (urls) {
    var image;
    for (var i = 0; i < urls.length; i++) {
      if (urls[i]) {
        image = new Image();
        image.src = urls[i];
      }
    }
  };

  /**
   * Preload element images.
   */
  Drupal.preloadElementImages = function (element) {
    var imagesUrls = [];

    $(element).find('img').each(function () {
      imagesUrls.push(this.src);
    });

    Drupal.preloadImages(imagesUrls);
  };

  /**
   * Return elements attribute value.
   */
  Drupal.getElementsAttributeValue = function ($elements, attributeName) {
    var values = [];

    $elements.each(function () {
      var attributeValue = $(this).attr(attributeName);
      if (attributeValue !== '') {
        values.push(attributeValue);
      }
    });

    return values;
  };

  /**
   * Return dialog content wrapper.
   */
  Drupal.getDrupalModalElement = function () {
    var $dialog = $('#drupal-modal');

    if ($dialog.length == 0) {
      $dialog = $('<div id="drupal-modal" class="ui-front"/>').appendTo('body');
    }

    return $dialog;
  }

  /**
   * Show content in modal dialog.
   */
  Drupal.showContentInDialog = function (content, dialogOptions) {
    var $dialog = Drupal.getDrupalModalElement();
    $dialog.append(content);
    Drupal.dialog($dialog, dialogOptions).showModal();
  }

  /**
   * Prevent default.
   */
  Drupal.preventDefault = function (element, eventName) {
    $(element).on(eventName, function (event) {
      event.preventDefault();
    });
  }

  /**
   * Return object from cookie.
   */
  Drupal.getObjectFromCookie = function (objectName) {
    var object = $.cookie(objectName);
    object = object ? JSON.parse(object) : {};
    return typeof(object) === 'object' ? object : {};
  }

  /**
   * Save object in cookie.
   */
  Drupal.saveObjectInCookie = function (objectName, object, expires) {
    expires = (typeof expires === 'undefined') ? 90 : expires;

    $.cookie(objectName, JSON.stringify(object), {
      path: drupalSettings.path.baseUrl,
      expires: expires,
    });
  }

  /**
   * Update object properties in cookie.
   */
  Drupal.updateObjectInCookie = function (objectName, newProperties, expires) {
    var object = Drupal.getObjectFromCookie(objectName);
    $.extend(object, newProperties);
    Drupal.saveObjectInCookie(objectName, object, expires);
  }

  /**
   * Return viewport height.
   */
  Drupal.getViewportHeight = function () {
    return window.innerHeight;
  }

})(jQuery);

==> improvements-2.1.0.tar.gz: improvements/assets/improvements.utils.js <==
(function ($) {

  /**
   * Beautifier browser url.
   */
  Drupal.beautifierBrowserUrl = function () {
    if (window.location.href.indexOf('%')) {
      window.history.replaceState(null, null, decodeURI(window.location.pathname) + decodeURI(window.location.search) + window.location.hash);
    }
  };

  /**
   * Replace string multiple.
   */
  Drupal.stringReplaceMultiple = function (string, values) {
    for (var searchValue in values) {
      if (values.hasOwnProperty(searchValue)) {
        string = string.replace(new RegExp(searchValue, 'g'), values[searchValue]);
      }
    }
    return string;
  };

  /**
   * Preload images.
   */
  Drupal.preloadImages = function (urls) {
    var image;
    for (var i = 0; i < urls.length; i++) {
      if (urls[i]) {
        image = new Image();
        image.src = urls[i];
      }
    }
  };

  /**
   * Preload element images.
   */
  Drupal.preloadElementImages = function (element) {
    var imagesUrls = [];

    $(element).find('img').each(function () {
      imagesUrls.push(this.src);
    });

    Drupal.preloadImages(imagesUrls);
  };

  /**
   * Return elements attribute value.
   */
  Drupal.getElementsAttributeValue = function ($elements, attributeName) {
    var values = [];

    $elements.each(function () {
      var attributeValue = $(this).attr(attributeName);
      if (attributeValue !== '') {
        values.push(attributeValue);
      }
    });

    return values;
  };

  /**
   * Return dialog content wrapper.
   */
  Drupal.getDrupalModalElement = function () {
    var $dialog = $('#drupal-modal');

    if ($dialog.length == 0) {
      $dialog = $('<div id="drupal-modal" class="ui-front"/>').appendTo('body');
    }

    return $dialog;
  }

  /**
   * Show content in modal dialog.
   */
  Drupal.showContentInDialog = function (content, dialogOptions) {
    var $dialog = Drupal.getDrupalModalElement();
    $dialog.append(content);
    Drupal.dialog($dialog, dialogOptions).showModal();
  }

  /**
   * Prevent default.
   */
  Drupal.preventDefault = function (element, eventName) {
    $(element).on(eventName, function (event) {
      event.preventDefault();
    });
  }

  /**
   * Return object from cookie.
   */
  Drupal.getObjectFromCookie = function (objectName) {
    var object = $.cookie(objectName);
    object = object ? JSON.parse(object) : {};
    return typeof(object) === 'object' ? object : {};
  }

  /**
   * Save object in cookie.
   */
  Drupal.saveObjectInCookie = function (objectName, object, expires) {
    expires = (typeof expires === 'undefined') ? 90 : expires;

    $.cookie(objectName, JSON.stringify(object), {
      path: drupalSettings.path.baseUrl,
      expires: expires,
    });
  }

  /**
   * Update object properties in cookie.
   */
  Drupal.updateObjectInCookie = function (objectName, newProperties, expires) {
    var object = Drupal.getObjectFromCookie(objectName);
    $.extend(object, newProperties);
    Drupal.saveObjectInCookie(objectName, object, expires);
  }

  /**
   * Return viewport height.
   */
  Drupal.getViewportHeight = function () {
    return window.innerHeight;
  }

  /**
   * Override function.
   */
  Drupal.functionOverride = function (object, functionName, options) {
    var originalFunction = object[functionName];

    object[functionName] = function () {
      if (options.before) {
        options.before.apply(this, arguments);
      }

      originalFunction.apply(this, arguments);

      if (options.after) {
        options.after.apply(this, arguments);
      }
    }
  }

})(jQuery);
